@@ -28,8 +28,7 @@
 #include "gdaemonvfs.h"
 #include "gvfsuriutils.h"
 #include "gdaemonfile.h"
-#include <gio/giomodule.h>
-#include <gio/gdummyfile.h>
+#include <gio/gio.h>
 #include <gvfsdaemonprotocol.h>
 #include <gmodule.h>
 #include "gvfsdaemondbus.h"
@@ -39,13 +38,6 @@
 #include "gdaemonvolumemonitor.h"
 #include <glib/gi18n-lib.h>
 
-#define G_TYPE_DAEMON_VFS		(g_daemon_vfs_get_type ())
-#define G_DAEMON_VFS(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), G_TYPE_DAEMON_VFS, GDaemonVfs))
-#define G_DAEMON_VFS_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), G_TYPE_DAEMON_VFS, GDaemonVfsClass))
-#define G_IS_DAEMON_VFS(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_TYPE_DAEMON_VFS))
-#define G_IS_DAEMON_VFS_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), G_TYPE_DAEMON_VFS))
-#define G_DAEMON_VFS_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), G_TYPE_DAEMON_VFS, GDaemonVfsClass))
-
 
 struct _GDaemonVfs
 {
@@ -181,6 +173,7 @@ g_daemon_vfs_init (GDaemonVfs *vfs)
   guint n_mappers;
   const char * const *schemes, * const *mount_types;
   GVfsUriMapper *mapper;
+  GList *modules;
   int i;
   
   vfs->async_bus = dbus_bus_get_private (DBUS_BUS_SESSION, NULL);
@@ -210,26 +203,31 @@ g_daemon_vfs_init (GDaemonVfs *vfs)
 
   _g_dbus_connection_integrate_with_main (vfs->async_bus);
 
-  g_io_modules_ensure_loaded (GVFS_MODULE_DIR);
+  modules = g_io_modules_load_all_in_directory (GVFS_MODULE_DIR);
 
   vfs->from_uri_hash = g_hash_table_new (g_str_hash, g_str_equal);
   vfs->to_uri_hash = g_hash_table_new (g_str_hash, g_str_equal);
   
   mappers = g_type_children (G_VFS_TYPE_URI_MAPPER, &n_mappers);
+
   for (i = 0; i < n_mappers; i++)
     {
+      int j;
       mapper = g_object_new (mappers[i], NULL);
 
       schemes = g_vfs_uri_mapper_get_handled_schemes (mapper);
 
-      for (i = 0; schemes != NULL && schemes[i] != NULL; i++)
-	g_hash_table_insert (vfs->from_uri_hash, (char *)schemes[i], mapper);
+      for (j = 0; schemes != NULL && schemes[j] != NULL; j++)
+	g_hash_table_insert (vfs->from_uri_hash, (char *)schemes[j], mapper);
       
       mount_types = g_vfs_uri_mapper_get_handled_mount_types (mapper);
-      for (i = 0; mount_types != NULL && mount_types[i] != NULL; i++)
-	g_hash_table_insert (vfs->to_uri_hash, (char *)mount_types[i], mapper);
+      for (j = 0; mount_types != NULL && mount_types[j] != NULL; j++)
+	g_hash_table_insert (vfs->to_uri_hash, (char *)mount_types[j], mapper);
     }
-  
+
+  /* The above should have ref:ed the modules anyway */
+  g_list_foreach (modules, (GFunc)g_type_module_unuse, NULL);
+  g_list_free (modules);
   g_free (mappers);
 }
 
@@ -264,7 +262,8 @@ g_daemon_vfs_get_file_for_uri (GVfs       *vfs,
       path = g_filename_from_uri (uri, NULL, NULL);
 
       if (path == NULL)
-	return g_dummy_file_new (uri);
+	/* Dummy file */
+	return g_vfs_get_file_for_uri (G_DAEMON_VFS (vfs)->wrapped_vfs, uri);
       
       file = g_daemon_vfs_get_file_for_path (vfs, path);
       g_free (path);
@@ -278,8 +277,9 @@ g_daemon_vfs_get_file_for_uri (GVfs       *vfs,
       g_free (path);
       return file;
     }
-  
-  return g_dummy_file_new (uri);
+
+  /* Dummy file */
+  return g_vfs_get_file_for_uri (G_DAEMON_VFS (vfs)->wrapped_vfs, uri);
 }
 
 char *
@@ -705,9 +705,7 @@ _g_daemon_vfs_get_mount_info_sync (GMountSpec *spec,
 
   if (!reply)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   "Error while getting mount info: %s",
-		   derror.message);
+      _g_error_from_dbus (&derror, error);
       dbus_error_free (&derror);
       return NULL;
     }
@@ -784,6 +782,7 @@ g_daemon_vfs_class_init (GDaemonVfsClass *class)
 /* Module API */
 
 void g_vfs_uri_mapper_smb_register (GIOModule *module);
+void g_vfs_uri_mapper_http_register (GIOModule *module);
 
 void
 g_io_module_load (GIOModule *module)
@@ -793,6 +792,7 @@ g_io_module_load (GIOModule *module)
 
   g_vfs_uri_mapper_register (module);
   g_vfs_uri_mapper_smb_register (module);
+  g_vfs_uri_mapper_http_register (module);
 }
 
 void
